@@ -66,7 +66,7 @@ void CntSymbianDatabase::initializeL()
 {
     User::LeaveIfNull(m_engine);
 
-#ifdef SYMBIAN_BACKEND_USE_SQLITE
+#ifdef SYMBIAN_BACKEND_USE_CNTMODEL_V2
     // 10.x platforms do not need some of CContactDatabase's concepts, so
     // they use the optimized OpenV2 and CreateV2.
     TRAPD(err, m_contactDatabase = CContactDatabase::OpenV2L());
@@ -87,7 +87,7 @@ void CntSymbianDatabase::initializeL()
     }
 #endif
 
-#ifndef SYMBIAN_BACKEND_USE_SQLITE
+#ifndef SYMBIAN_BACKEND_USE_CNTMODEL_V2
     // In pre 10.1 platforms the AddObserverL & RemoveObserver functions are not
     // exported so we need to use CContactChangeNotifier.
     TRAP(err, m_contactChangeNotifier = CContactChangeNotifier::NewL(*m_contactDatabase, this));
@@ -110,7 +110,7 @@ void CntSymbianDatabase::initializeL()
     // EContactDbObserverEventGroupMembersAdded and 
     // EContactDbObserverEventGroupMembersRemoved need to be added to
     // MContactDbObserver.
-#ifndef SYMBIAN_BACKEND_USE_SQLITE
+#ifndef SYMBIAN_BACKEND_USE_CNTMODEL_V2
     updateGroupMembershipsL();
 #endif
 }
@@ -118,7 +118,7 @@ void CntSymbianDatabase::initializeL()
 CntSymbianDatabase::~CntSymbianDatabase()
 {
     m_engine = NULL;
-#ifndef SYMBIAN_BACKEND_USE_SQLITE
+#ifndef SYMBIAN_BACKEND_USE_CNTMODEL_V2
     delete m_contactChangeNotifier;
 #else
     if (m_contactDatabase != 0) {
@@ -347,7 +347,7 @@ void CntSymbianDatabase::HandleDatabaseEventL(TContactDbObserverEvent aEvent)
     changeSet.emitSignals(m_engine);
 }
 
-#ifdef SYMBIAN_BACKEND_USE_SQLITE  
+#ifdef SYMBIAN_BACKEND_USE_CNTMODEL_V2  
 /*!
  * Respond to a contacts database extended event, delegating this event to
  * an appropriate signal as required.
@@ -360,30 +360,65 @@ void CntSymbianDatabase::HandleDatabaseEventV2L(TContactDbObserverEventV2 aEvent
     QContactChangeSet changeSet;
     switch (aEvent.iTypeV2)
     {
-    case EContactDbObserverEventV2ContactAddedToGroup:
-        if (m_contactsEmitted.contains(aEvent.iContactId) && 
-            m_contactsEmitted.contains(aEvent.iAdditionalContactId)) {
-            m_contactsEmitted.removeOne(aEvent.iContactId);
-            m_contactsEmitted.removeOne(aEvent.iAdditionalContactId);
+    case EContactDbObserverEventV2ContactsAddedToGroup:
+        if (aEvent.iAdditionalContactIds != NULL) {
+            if (m_contactsEmitted.contains(aEvent.iContactId))
+                {
+                // Group id is in the list of emitted events, so remove 
+                // group id and all affected contacts from this list.
+                m_contactsEmitted.removeOne(aEvent.iContactId);
+                for (int i = 0; i < aEvent.iAdditionalContactIds->Count(); i++) {
+                    int id = aEvent.iAdditionalContactIds->operator[](i);
+                    m_contactsEmitted.removeOne(id);
+                    }
+                }
+            else {
+                // No signal was sent yet, update changeSet
+                QList<QContactLocalId> affectedContactIds;
+                affectedContactIds.append(aEvent.iContactId);
+                for (int i = 0; i < aEvent.iAdditionalContactIds->Count(); i++) {
+                    int id = aEvent.iAdditionalContactIds->operator[](i);
+                    affectedContactIds.append(id);
+                }
+                changeSet.insertAddedRelationshipsContacts(affectedContactIds);
             }
-        else {
-            QList<QContactLocalId> affectedContactIds;
-            affectedContactIds.append(aEvent.iContactId);
-            affectedContactIds.append(aEvent.iAdditionalContactId);
-            changeSet.insertAddedRelationshipsContacts(affectedContactIds);
         }
         break;
-    case EContactDbObserverEventV2ContactRemovedFromGroup:
-        if (m_contactsEmitted.contains(aEvent.iContactId) && 
-            m_contactsEmitted.contains(aEvent.iAdditionalContactId)) {
-            m_contactsEmitted.removeOne(aEvent.iContactId);
-            m_contactsEmitted.removeOne(aEvent.iAdditionalContactId);
+    case EContactDbObserverEventV2ContactsRemovedFromGroup:
+        if (aEvent.iAdditionalContactIds != NULL) {
+            if (m_contactsEmitted.contains(aEvent.iContactId))
+                {
+                // Group id is in the list of emitted events, so remove 
+                // group id and all affected contacts from this list.
+                m_contactsEmitted.removeOne(aEvent.iContactId);
+                for (int i = 0; i < aEvent.iAdditionalContactIds->Count(); i++) {
+                    int id = aEvent.iAdditionalContactIds->operator[](i);
+                    m_contactsEmitted.removeOne(id);
+                    }
+                }
+            else {
+                // No signal was sent yet, update changeSet
+                QList<QContactLocalId> affectedContactIds;
+                affectedContactIds.append(aEvent.iContactId);
+                for (int i = 0; i < aEvent.iAdditionalContactIds->Count(); i++) {
+                    int id = aEvent.iAdditionalContactIds->operator[](i);
+                    affectedContactIds.append(id);
+                }
+                changeSet.insertRemovedRelationshipsContacts(affectedContactIds);
+            }
+        }
+        break;
+    case EContactDbObserverEventV2ContactsOrGroupsDeleted:
+        if (aEvent.iAdditionalContactIds != NULL) {
+            for (int i = 0; i < aEvent.iAdditionalContactIds->Count(); i++) {
+                int id = aEvent.iAdditionalContactIds->operator[](i);
+                if(m_contactsEmitted.contains(id)) {
+                    m_contactsEmitted.removeOne(id);
+                }
+                else {
+                    changeSet.insertRemovedContact(id);
+                }
             }
-        else {
-            QList<QContactLocalId> affectedContactIds;
-            affectedContactIds.append(aEvent.iContactId);
-            affectedContactIds.append(aEvent.iAdditionalContactId);
-            changeSet.insertRemovedRelationshipsContacts(affectedContactIds);
         }
         break;
     case EContactDbObserverEventV2GroupChanged:
